jsTree v.1.0 - themeroller documentation

# jsTree v.1.0 - themeroller plugin

## Description

The `themeroller` plugin adds support for jQuery UI's themes. Add the plugin as last in your `plugins` config option. Also make sure that you have included the jquery theme you'd like to use and you should NOT use the native jstree `themes` plugin.

## Configuration

### opened

A string. Default is `"ui-icon-triangle-1-se"`.

The class name to use for open nodes (shows the arrow to close).

### closed

A string. Default is `"ui-icon-triangle-1-e"`.

The class name to use for closed nodes (shows the arrow to open).

### item

A string. Default is `"ui-state-default"`.

The class name to use for the actual items.

### item_h

A string. Default is `"ui-state-hover"`.

The class name to use for the hovered item.

### item_a

A string. Default is `"ui-state-active"`.

The class name to use for selected items (UI plugin).

### item_icon

A string. Default is `"ui-icon-folder-collapsed"`.

The class name to use for the default icon.

## Demos

### Using the themeroller plugin

- Root node 1
  - Child node 1
  - Child node 2
- Root node 2

## API

### ._themeroller ( obj )

Fixes the tree on various events by applying the configured classes - used internally only.